@@ -13,7 +13,10 @@ class socket_talker(object):
         self.port = port
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.sock.settimeout(3)
-        self.sock.connect((host, port))
+        try:
+       	    self.sock.connect((host, port))
+       	except socket.error, msg:
+       	    print 'Cannot connect to MPD:', msg
         self.file = self.sock.makefile("rb+")
         self.current_line = ''
         self.ack = ''
@@ -130,6 +133,7 @@ commands = {
 
     # <string type> <string what>
     ("find",   2): ('%s "%s" "%s"', MANY, '', plitem_delim),
+    ("rename", 2): ('%s "%s" "%s"', ZERO, '', []),
 
     # <string type> <string what>
     ("search", 2): ('%s "%s" "%s"', MANY, '', plitem_delim),
@@ -328,9 +332,8 @@ def connect(**kw):
     password, host = parse_host(os.environ.get('MPD_HOST', 'localhost'))
     host = kw.get('host', host)
     password = kw.get('password', password)
-
+    
     conn = mpd_connection(host, port, password)
-    #if password:
-    #    conn.password(password)
+    if password:
+        conn.do.password(password)
     return conn
-
